@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2020 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -64,7 +64,7 @@ void
 Fs::Ufs::UFSStoreState::openDone()
 {
     if (closing)
-        debugs(0, DBG_CRITICAL, HERE << "already closing in openDone()!?");
+        debugs(0, DBG_CRITICAL, "already closing in openDone()!?");
 
     if (theFile->error()) {
         tryClosing();
@@ -95,7 +95,7 @@ Fs::Ufs::UFSStoreState::closeCompleted()
            theFile->error());
 
     if (theFile->error()) {
-        debugs(79,3,HERE<< "theFile->error() ret " << theFile->error());
+        debugs(79,3, "theFile->error() ret " << theFile->error());
         doCloseCallback(DISK_ERROR);
     } else {
         doCloseCallback(DISK_OK);
@@ -124,8 +124,8 @@ Fs::Ufs::UFSStoreState::close(int)
 void
 Fs::Ufs::UFSStoreState::read_(char *buf, size_t size, off_t aOffset, STRCB * aCallback, void *aCallbackData)
 {
-    assert(read.callback == NULL);
-    assert(read.callback_data == NULL);
+    assert(read.callback == nullptr);
+    assert(read.callback_data == nullptr);
     assert(!reading);
     assert(!closing);
     assert (aCallback);
@@ -162,8 +162,8 @@ Fs::Ufs::UFSStoreState::write(char const *buf, size_t size, off_t aOffset, FREE
            std::setfill('0') << std::hex << std::uppercase << std::setw(8) << swap_filen);
 
     if (theFile->error()) {
-        debugs(79, DBG_IMPORTANT,HERE << "avoid write on theFile with error");
-        debugs(79, DBG_IMPORTANT,HERE << "calling free_func for " << (void*) buf);
+        debugs(79, DBG_IMPORTANT, "ERROR: avoid write on theFile with error");
+        debugs(79, DBG_IMPORTANT, "calling free_func for " << (void*) buf);
         free_func((void*)buf);
         return false;
     }
@@ -204,7 +204,7 @@ Fs::Ufs::UFSStoreState::doWrite()
     auto &q = pending_writes.front();
 
     if (theFile->error()) {
-        debugs(79, DBG_IMPORTANT, MYNAME << " avoid write on theFile with error");
+        debugs(79, DBG_IMPORTANT, "ERROR: " << MYNAME << "avoid write on theFile with error");
         pending_writes.pop();
         return;
     }
@@ -242,7 +242,7 @@ Fs::Ufs::UFSStoreState::readCompleted(const char *buf, int len, int, RefCount<Re
 
     assert(callback_);
 
-    read.callback = NULL;
+    read.callback = nullptr;
 
     void *cbdata;
 
@@ -251,7 +251,7 @@ Fs::Ufs::UFSStoreState::readCompleted(const char *buf, int len, int, RefCount<Re
      * occur strictly after reads and writes.
      * ufs doesn't queue, it simply completes, so close callbacks occur
      * strictly after reads and writes.
-     * aufs performs closes syncronously, so close events must be managed
+     * aufs performs closes synchronously, so close events must be managed
      * to force strict ordering.
      * The below does this:
      * closing is set when theFile->close() has been called, and close only triggers
@@ -265,14 +265,14 @@ Fs::Ufs::UFSStoreState::readCompleted(const char *buf, int len, int, RefCount<Re
         callback_(cbdata, read_buf, len, this);
     }
 
-    if (flags.try_closing || (theFile != NULL && theFile->error()) )
+    if (flags.try_closing || (theFile != nullptr && theFile->error()) )
         tryClosing();
 }
 
 void
 Fs::Ufs::UFSStoreState::writeCompleted(int, size_t len, RefCount<WriteRequest>)
 {
-    debugs(79, 3, HERE << "dirno " << swap_dirn << ", fileno " <<
+    debugs(79, 3, "dirno " << swap_dirn << ", fileno " <<
            std::setfill('0') << std::hex << std::uppercase << std::setw(8) << swap_filen <<
            ", len " << len);
     /*
@@ -284,7 +284,7 @@ Fs::Ufs::UFSStoreState::writeCompleted(int, size_t len, RefCount<WriteRequest>)
     offset_ += len;
 
     if (theFile->error()) {
-        debugs(79,2,HERE << " detected an error, will try to close");
+        debugs(79,2, " detected an error, will try to close");
         tryClosing();
     }
 
@@ -308,7 +308,7 @@ Fs::Ufs::UFSStoreState::doCloseCallback(int errflag)
      */
     freePending();
     STIOCB *theCallback = callback;
-    callback = NULL;
+    callback = nullptr;
 
     void *cbdata;
 
@@ -320,19 +320,19 @@ Fs::Ufs::UFSStoreState::doCloseCallback(int errflag)
      * us that the file has been closed.  This must be the last line,
      * as theFile may be the only object holding us in memory.
      */
-    theFile = NULL; // refcounted
+    theFile = nullptr; // refcounted
 }
 
 /* ============= THE REAL UFS CODE ================ */
 
 Fs::Ufs::UFSStoreState::UFSStoreState(SwapDir * SD, StoreEntry * anEntry, STIOCB * cbIo, void *data) :
-    StoreIOState(NULL, cbIo, data),
+    StoreIOState(cbIo, data),
     opening(false),
     creating(false),
     closing(false),
     reading(false),
     writing(false),
-    read_buf(NULL)
+    read_buf(nullptr)
 {
     // StoreIOState inherited members
     swap_filen = anEntry->swap_filen;
@@ -429,13 +429,13 @@ Fs::Ufs::UFSStoreState::drainWriteQueue()
 void
 Fs::Ufs::UFSStoreState::tryClosing()
 {
-    debugs(79,3,HERE << this << " tryClosing()" <<
+    debugs(79,3, this << " tryClosing()" <<
            " closing = " << closing <<
            " flags.try_closing = " << flags.try_closing <<
            " ioInProgress = " << theFile->ioInProgress());
 
     if (theFile->ioInProgress()) {
-        debugs(79, 3, HERE << this <<
+        debugs(79, 3, this <<
                " won't close since ioInProgress is true, bailing");
         flags.try_closing = true;
         return;
